@@ -14,40 +14,37 @@ MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 Lesser General Public License for more details.
 
 You should have received a copy of the GNU Lesser General Public
-License along with this library; if not, see 
+License along with this library; if not, see
 <http://www.gnu.org/licenses/lgpl-2.1.html>.
 */
 
-#ifndef  __TRACE_H__
-#define  __TRACE_H__
+#ifndef  SRC_TRACE_H_
+#define  SRC_TRACE_H_
 
 #include <stdio.h>
 #include <glib.h>
 
+#include <string>
+
 #include "exports.h"
 #include "gpsim_classes.h"
+#include "gpsim_object.h"
 #include "trigger.h"
-#include "value.h"
 #include "registers.h"
 
-extern "C"
-{
-#include "lxt_write.h"
-}
-
 class Processor;
 class Trace;
-
-
-
 class TraceFrame;
+class Module;
+class XrefObject;
+class ModuleTraceType;
+
 //========================================================================
 // A 'TraceObject' is created when the contents of the Trace buffer are
 // displayed. The TraceObjects are placed into TraceFrames, and eventually
 // the entire frame is displayed.
 
-class TraceObject
-{
+class TraceObject {
 public:
   TraceObject();
 
@@ -55,13 +52,13 @@ public:
   {
   }
 
-  virtual void print(FILE *)=0;
-  virtual void print_frame(TraceFrame *,FILE *);
+  virtual void print(FILE *) = 0;
+  virtual void print_frame(TraceFrame *, FILE *);
   virtual void getState(TraceFrame *);   // FIXME Is this even used?
 };
 
-class CycleTraceObject : public TraceObject
-{
+
+class CycleTraceObject : public TraceObject {
 public:
   CycleTraceObject();
 
@@ -69,31 +66,31 @@ public:
   {
   }
 
-  virtual void print(FILE *);
-  virtual void print_frame(TraceFrame *,FILE *);
-  virtual void getState(TraceFrame *);
+  virtual void print(FILE *) override;
+  virtual void print_frame(TraceFrame *, FILE *) override;
+  virtual void getState(TraceFrame *) override;
 };
 
-class InvalidTraceObject : public TraceObject
-{
+
+class InvalidTraceObject : public TraceObject {
 public:
-  InvalidTraceObject(int type);
+  explicit InvalidTraceObject(int type);
 
   virtual ~InvalidTraceObject()
   {
   }
 
-  virtual void print(FILE *);
+  virtual void print(FILE *) override;
 protected:
   int mType;
 };
 
-class ProcessorTraceObject : public TraceObject
-{
+
+class ProcessorTraceObject : public TraceObject {
 public:
   Processor *cpu;
 
-  ProcessorTraceObject(Processor *_cpu) : TraceObject() , cpu(_cpu)
+  explicit ProcessorTraceObject(Processor *_cpu) : TraceObject(), cpu(_cpu)
   {
   }
 
@@ -101,12 +98,11 @@ public:
   {
   }
 
-  virtual void print(FILE *)=0;
+  virtual void print(FILE *) = 0;
 };
 
-class ModuleTraceType;
-class ModuleTraceObject : public TraceObject
-{
+
+class ModuleTraceObject : public TraceObject {
 public:
   Module *pModule;
   ModuleTraceType *pModuleTraceType;
@@ -115,7 +111,7 @@ public:
   ModuleTraceObject(Module *_module,
                     ModuleTraceType *pmtt,
                     unsigned int d)
-    : TraceObject() ,
+    : TraceObject(),
       pModule(_module),
       pModuleTraceType(pmtt),
       mTracedData(d)
@@ -126,11 +122,11 @@ public:
   {
   }
 
-  virtual void print(FILE *);
+  virtual void print(FILE *) override;
 };
 
-class RegisterWriteTraceObject : public ProcessorTraceObject
-{
+
+class RegisterWriteTraceObject : public ProcessorTraceObject {
 public:
   Register *reg;
   RegisterValue from;
@@ -142,12 +138,12 @@ public:
   {
   }
 
-  virtual void print(FILE *);
-  virtual void getState(TraceFrame *);
+  virtual void print(FILE *) override;
+  virtual void getState(TraceFrame *) override;
 };
 
-class RegisterReadTraceObject : public RegisterWriteTraceObject
-{
+
+class RegisterReadTraceObject : public RegisterWriteTraceObject {
 public:
   RegisterReadTraceObject(Processor *_cpu, Register *_reg, RegisterValue trv);
 
@@ -155,12 +151,12 @@ public:
   {
   }
 
-  virtual void print(FILE *);
-  virtual void getState(TraceFrame *);
+  virtual void print(FILE *) override;
+  virtual void getState(TraceFrame *) override;
 };
 
-class PCTraceObject : public ProcessorTraceObject
-{
+
+class PCTraceObject : public ProcessorTraceObject {
 public:
   unsigned int address;
 
@@ -170,10 +166,11 @@ public:
   {
   }
 
-  virtual void print(FILE *);
-  virtual void print_frame(TraceFrame *,FILE *);
+  virtual void print(FILE *) override;
+  virtual void print_frame(TraceFrame *, FILE *) override;
 };
 
+
 //========================================================================
 // The TraceType class is the base class for the various trace types that
 // are supported by gpsim. In general, when a trace type is created,
@@ -184,26 +181,29 @@ public:
 // the trace buffer. The whole 32 bits are then written to the trace buffer
 // array.
 
-class TraceType
-{
+class TraceType {
 public:
-
-
   TraceType(unsigned int nTraceEntries, const char *desc);
 
   virtual ~TraceType()
   {
   }
 
-  void setType(unsigned int t) { mType = t;}
+  void setType(unsigned int t)
+  {
+    mType = t;
+  }
   // The actual type of the TraceType is an 8-bit field in the
   // upper 32-bits of an unsigned integer. A TraceType can have
   // more than one type, although the types are consecutive.
-  unsigned int type(unsigned int iType=0)
+  unsigned int type(unsigned int iType = 0)
   {
-    return (iType<mSize) ? (mType + (iType<<24)) : mType;
+    return (iType < mSize) ? (mType + (iType << 24)) : mType;
+  }
+  unsigned int size()
+  {
+    return mSize;
   }
-  unsigned int size() { return mSize; }
 
   // Given an index into the trace buffer, decode()
   // will fetch traced items at that trace buffer index
@@ -219,51 +219,58 @@ public:
   // were used to record this TraceType event. The default
   // is the size allocated for this type.
 
-  virtual int entriesUsed(Trace *,unsigned int tbi);
+  virtual int entriesUsed(Trace *, unsigned int tbi);
 
-  virtual bool isFrameBoundary() { return false;}
+  virtual bool isFrameBoundary()
+  {
+    return false;
+  }
   // Returns true if the trace record starting at index 'tbi' is of the same
   // type as this TraceType
   virtual bool isValid(Trace *, unsigned int tbi);
   // Returns true if the type of 'aType' is the same type as this TraceType
   bool isValid(unsigned int aType)
   {
-    unsigned int tMask=0xff<<24;
-    return ((aType&tMask) >= (mType&tMask))  && ((aType&tMask) <= ((mType&tMask) + (mSize<<24)));
+    unsigned int tMask = 0xff << 24;
+    return ((aType & tMask) >= (mType & tMask))  && ((aType & tMask) <= ((mType & tMask) + (mSize << 24)));
   }
-  virtual int bitsTraced() { return 24; }
-  virtual int dump_raw(Trace *,unsigned tbi, char *buf, int bufsize);
+  virtual int bitsTraced()
+  {
+    return 24;
+  }
+  virtual int dump_raw(Trace *, unsigned tbi, char *buf, int bufsize);
 
   // Debugging - provide a way to see the TraceTypes that have been allocated.
   virtual void showInfo();
   const char *cpDescription();
-private:
-  unsigned int mType;           // The integer type is dynamically
-                                // assigned by the Trace class.
-  unsigned int mSize;           // The number of positions this
-                                // type occupies
-protected:
-  const char *mpDescription;    //
 
+private:
+  unsigned int mType = 0;           // The integer type is dynamically
+  // assigned by the Trace class.
+  unsigned int mSize;           // The number of positions this
+  // type occupies
+
+protected:
+  const char *mpDescription;
 };
 
-class CycleTraceType : public TraceType
-{
+
+class CycleTraceType : public TraceType {
 public:
-  CycleTraceType(unsigned int nTraceEntries);
+  explicit CycleTraceType(unsigned int nTraceEntries);
 
   virtual ~CycleTraceType()
   {
   }
 
-  virtual TraceObject *decode(unsigned int tbi);
-  virtual bool isFrameBoundary();
-  virtual int dump_raw(Trace *,unsigned tbi, char *buf, int bufsize);
-  virtual int entriesUsed(Trace *,unsigned int tbi);
+  virtual TraceObject *decode(unsigned int tbi) override;
+  virtual bool isFrameBoundary() override;
+  virtual int dump_raw(Trace *, unsigned tbi, char *buf, int bufsize) override;
+  virtual int entriesUsed(Trace *, unsigned int tbi) override;
 };
 
-class ModuleTraceType : public TraceType
-{
+
+class ModuleTraceType : public TraceType {
 public:
   Module *pModule;
   ModuleTraceType(Module *_pModule,
@@ -274,13 +281,12 @@ public:
   {
   }
 
-  virtual TraceObject *decode(unsigned int tbi);
-  virtual int dump_raw(Trace *,unsigned tbi, char *buf, int bufsize);
-
+  virtual TraceObject *decode(unsigned int tbi) override;
+  virtual int dump_raw(Trace *, unsigned tbi, char *buf, int bufsize) override;
 };
 
-class ProcessorTraceType : public TraceType
-{
+
+class ProcessorTraceType : public TraceType {
 public:
   Processor *cpu;
 
@@ -293,11 +299,10 @@ public:
   }
 
   virtual TraceObject *decode(unsigned int tbi) = 0;
-
 };
 
-class PCTraceType : public ProcessorTraceType
-{
+
+class PCTraceType : public ProcessorTraceType {
 public:
   PCTraceType(Processor *_cpu, unsigned int nTraceEntries);
 
@@ -305,43 +310,44 @@ public:
   {
   }
 
-  virtual TraceObject *decode(unsigned int tbi);
-  virtual bool isFrameBoundary() { return true; }
-  virtual int dump_raw(Trace *,unsigned tbi, char *buf, int bufsize);
+  virtual TraceObject *decode(unsigned int tbi) override;
+  virtual bool isFrameBoundary() override
+  {
+    return true;
+  }
+  virtual int dump_raw(Trace *, unsigned tbi, char *buf, int bufsize) override;
 };
 
-class RegisterWriteTraceType : public ProcessorTraceType
-{
-public:
 
+class RegisterWriteTraceType : public ProcessorTraceType {
+public:
   RegisterWriteTraceType(Processor *_cpu, unsigned int nTraceEntries);
 
   virtual ~RegisterWriteTraceType()
   {
   }
 
-  virtual TraceObject *decode(unsigned int tbi);
-  virtual int dump_raw(Trace *,unsigned tbi, char *buf, int bufsize);
+  virtual TraceObject *decode(unsigned int tbi) override;
+  virtual int dump_raw(Trace *, unsigned tbi, char *buf, int bufsize) override;
 };
 
-class RegisterReadTraceType : public ProcessorTraceType
-{
-public:
 
+class RegisterReadTraceType : public ProcessorTraceType {
+public:
   RegisterReadTraceType(Processor *_cpu, unsigned int nTraceEntries);
 
   virtual ~RegisterReadTraceType()
   {
   }
 
-  virtual TraceObject *decode(unsigned int tbi);
-  virtual int dump_raw(Trace *,unsigned tbi, char *buf, int bufsize);
+  virtual TraceObject *decode(unsigned int tbi) override;
+  virtual int dump_raw(Trace *, unsigned tbi, char *buf, int bufsize) override;
 };
 
+
 // Trace Type for Resets
 
-class ResetTraceObject : public ProcessorTraceObject
-{
+class ResetTraceObject : public ProcessorTraceObject {
 public:
   ResetTraceObject(Processor *_cpu, RESET_TYPE r);
 
@@ -354,18 +360,18 @@ protected:
   RESET_TYPE m_reset;
 };
 
-class ResetTraceType : public ProcessorTraceType
-{
+
+class ResetTraceType : public ProcessorTraceType {
 public:
-  ResetTraceType(Processor *_cpu);
+  explicit ResetTraceType(Processor *_cpu);
 
   virtual ~ResetTraceType()
   {
   }
 
-  TraceObject *decode(unsigned int tbi);
+  TraceObject *decode(unsigned int tbi) override;
   void record(RESET_TYPE r);
-  int dump_raw(Trace *pTrace,unsigned int tbi, char *buf, int bufsize);
+  int dump_raw(Trace *pTrace, unsigned int tbi, char *buf, int bufsize) override;
 
   unsigned int m_uiTT;
 };
@@ -378,61 +384,60 @@ public:
 // of time. When the trace buffer is decoded, markers will be examined
 // to determine the frame boundaries.
 
-class TraceFrame
-{
+class TraceFrame {
 public:
-  list <TraceObject *> traceObjects;
-  guint64 cycle_time;
+  std::list<TraceObject *> traceObjects;
+  guint64 cycle_time = 0;
 
   TraceFrame();
   virtual ~TraceFrame();
+
   virtual void add(TraceObject *to);
   virtual void print(FILE *);
-  virtual void update_state(void);
+  virtual void update_state();
 };
 
-//-----------------------------------------------------------
-class TraceRawLog
-{
-public:
 
-  char *log_filename;
-  FILE *log_file;
+//-----------------------------------------------------------
+class TraceRawLog {
+public:
+  TraceRawLog();
+  ~TraceRawLog();
 
   void log();
   void enable(const char*);
   void disable();
 
-  TraceRawLog();
-  ~TraceRawLog();
-
+private:
+  std::string log_filename;
+  FILE *log_file = nullptr;
 };
+
+
 //------------------------------------------------------------
-class traceValue : public gpsimObject
-{
- public:
+class traceValue : public gpsimObject {
+public:
   traceValue();
-  virtual void put_value(unsigned int new_value) {};
+  virtual void put_value(unsigned int ) {}
   virtual unsigned int get_value();
 };
+
+
 //---------------------------------------------------------
 // Class for trace buffer
 
-class Trace
-{
-  public:
-
+class Trace {
+public:
   enum eTraceTypes {
     NOTHING            =  0x3fffffff,
-    LAST_TRACE_TYPE    = (1<<24),
+    LAST_TRACE_TYPE    = (1 << 24),
 
-    TYPE_MASK          = (0xff<<24),
-    CYCLE_COUNTER_LO   = (0x80<<24),
-    CYCLE_COUNTER_MI   = (0x40<<24),
-    CYCLE_COUNTER_HI   = (0xC0<<24)
+    TYPE_MASK          = (0xff << 24),
+    CYCLE_COUNTER_LO   = (0x80 << 24),
+    CYCLE_COUNTER_MI   = (0x40 << 24),
+    CYCLE_COUNTER_HI   = (0xC0 << 24)
   };
 
-
 #define    TRACE_BUFFER_SIZE  (1<<12)
 #define    TRACE_BUFFER_MASK  (TRACE_BUFFER_SIZE-1)
 #define    TRACE_BUFFER_NEAR_FULL  (TRACE_BUFFER_SIZE * 3 /4)
@@ -440,8 +445,8 @@ class Trace
 
   unsigned int trace_buffer[TRACE_BUFFER_SIZE];
   unsigned int trace_index;
-  unsigned int trace_flag;
-  bool bLogging;
+  unsigned int trace_flag = 0;
+  bool bLogging = false;
   TraceRawLog logger;
 
   traceValue trace_value;
@@ -452,25 +457,27 @@ class Trace
   // is notified that new data is available in the string_buffer).
   XrefObject *xref;
   char  string_buffer[TRACE_STRING_BUFFER];
-  guint64 string_cycle;          // The cycle corresponding to the decoded string
-  unsigned int string_index;     // The trace buffer index corresponding "   "
+  guint64 string_cycle = 0;          // The cycle corresponding to the decoded string
+  unsigned int string_index = 0;     // The trace buffer index corresponding "   "
 
-  Processor *cpu;
+  Processor *cpu = nullptr;
 
-  TraceFrame *current_frame;
+  TraceFrame *current_frame = nullptr;
   guint64 current_cycle_time;      // used when decoding the trace buffer.
-  list <TraceFrame *> traceFrames;
-  unsigned int lastTraceType;
-  unsigned int lastSubTraceType;
+  std::list<TraceFrame *> traceFrames;
+  unsigned int lastTraceType = LAST_TRACE_TYPE;
+  unsigned int lastSubTraceType = 1 << 16;
 
-  Trace (void);
-  ~Trace(void);
+  Trace();
+  Trace(const Trace &) = delete;
+  Trace & operator = (const Trace &) = delete;
+  ~Trace();
 
   // trace raw allows any value to be written to the trace buffer.
   // This is useful for modules that wish to trace things, but do
   // not wish to modify the Trace class.
 
-  inline void raw (unsigned int ui)
+  inline void raw(unsigned int ui)
   {
     trace_buffer[trace_index] = ui;
     trace_index = (trace_index + 1) & TRACE_BUFFER_MASK;
@@ -485,25 +492,29 @@ class Trace
   }
   */
 
-  inline void cycle_counter (guint64 cc)
+  inline void cycle_counter(guint64 cc)
   {
     // The 64 bit cycle counter requires three 24 bit traces.
     trace_buffer[trace_index] = (unsigned int)(CYCLE_COUNTER_LO | (cc & 0xffffff));
     trace_index = (trace_index + 1) & TRACE_BUFFER_MASK;
-    trace_buffer[trace_index] = (unsigned int)(CYCLE_COUNTER_MI | (cc>>24));
+    trace_buffer[trace_index] = (unsigned int)(CYCLE_COUNTER_MI | (cc >> 24));
     trace_index = (trace_index + 1) & TRACE_BUFFER_MASK;
-    trace_buffer[trace_index] = (unsigned int)(CYCLE_COUNTER_HI | (cc>>48));
+    trace_buffer[trace_index] = (unsigned int)(CYCLE_COUNTER_HI | (cc >> 48));
     trace_index = (trace_index + 1) & TRACE_BUFFER_MASK;
   }
-  inline bool near_full(void) {
+  inline bool near_full()
+  {
     return (trace_index > TRACE_BUFFER_NEAR_FULL);
   }
 
-  void switch_cpus(Processor *new_cpu) {cpu = new_cpu;};
+  void switch_cpus(Processor *new_cpu)
+  {
+    cpu = new_cpu;
+  }
 
-  int  dump (int n=0, FILE *out_stream=0);
-  void dump_last_instruction(void);
-  int  dump1(unsigned int,char *, int);
+  int  dump(int n = 0, FILE *out_stream = nullptr);
+  void dump_last_instruction();
+  int  dump1(unsigned int, char *, int);
   void dump_raw(int n);
 
   // tbi - trace buffer index masking.
@@ -519,15 +530,16 @@ class Trace
   {
     i = tbi(i);
 
-    if( low < high)
+    if (low < high) {
       return (i >= low && i <= high);
+    }
+
     // Looks like the range straddles the roll over boundary.
     return (i >= low || i <= high);
   }
 
-
   // get() return the trace entry at 'index'
-  inline unsigned int operator [] (unsigned int index)
+  inline unsigned int operator [](unsigned int index)
   {
     return trace_buffer[tbi(index)];
   }
@@ -555,23 +567,23 @@ class Trace
   // Trace frame manipulation
   void addFrame(TraceFrame *newFrame);
   void addToCurrentFrame(TraceObject *to);
-  void deleteTraceFrame(void);
+  void deleteTraceFrame();
   void printTraceFrame(FILE *);
 
   // Display information about allocated traces.
   void showInfo();
-
 };
 
+
 #if defined(IN_MODULE) && defined(_WIN32)
 // we are in a module: don't access trace object directly!
-LIBGPSIM_EXPORT Trace & get_trace(void);
+LIBGPSIM_EXPORT Trace & get_trace();
 #else
 // we are in gpsim: use of get_trace() is recommended,
 // even if trace object can be accessed directly.
 extern Trace trace;
 
-inline Trace &get_trace(void)
+inline Trace &get_trace()
 {
   return trace;
 }
@@ -581,32 +593,33 @@ inline Trace &get_trace(void)
 //-----------------------------------------------------------
 #define TRACE_FILE_FORMAT_ASCII 0
 #define TRACE_FILE_FORMAT_LXT 1
-class TraceLog : public TriggerObject
-{
+class TraceLog : public TriggerObject {
 public:
-  bool logging;
-  bool lograw;
-  int items_logged;
-  char *log_filename;
-  FILE *log_file;
-  Processor *cpu;
-  unsigned int last_trace_index;
+  bool logging = false;
+  bool lograw = false;
+  int items_logged = 0;
+private:
+  std::string log_filename;
+public:
+  FILE *log_file = nullptr;
+  Processor *cpu = nullptr;
+  unsigned int last_trace_index = 0;
   Trace buffer;
-  int file_format;
-  struct lt_trace *lxtp;
-  struct lt_symbol *symp;
+  int file_format = 0;
+  struct lt_trace *lxtp = nullptr;
+  struct lt_symbol *symp = nullptr;
 
-  TraceLog(void);
-  ~TraceLog(void);
+  TraceLog();
+  ~TraceLog();
 
-  virtual void callback(void);
-  void enable_logging(const char *new_filename=0, int format=TRACE_FILE_FORMAT_ASCII);
-  void disable_logging(void);
+  virtual void callback() override;
+  void enable_logging(const char *new_filename = nullptr, int format = TRACE_FILE_FORMAT_ASCII);
+  void disable_logging();
   void switch_cpus(Processor *new_cpu);
   void open_logfile(const char *new_fname, int format);
-  void close_logfile(void);
-  void write_logfile(void);
-  void status(void);
+  void close_logfile();
+  void write_logfile();
+  void status();
 
   void lxt_trace(unsigned int address, unsigned int value, guint64 cc);
 
@@ -614,18 +627,18 @@ public:
   void register_write(Register *, guint64 cc);
   void register_read_value(Register *, guint64 cc);
   void register_write_value(Register *, guint64 cc);
-
 };
 
+
 #if defined(_WIN32)
 // we are in a module: don't access trace_log object directly!
-LIBGPSIM_EXPORT TraceLog & GetTraceLog(void);
+LIBGPSIM_EXPORT TraceLog & GetTraceLog();
 #else
 // we are in gpsim: use of GetTraceLog() is recommended,
 // even if trace_log object can be accessed directly.
 extern TraceLog trace_log;
 
-inline TraceLog &GetTraceLog(void)
+inline TraceLog &GetTraceLog()
 {
   return trace_log;
 }
@@ -633,26 +646,25 @@ inline TraceLog &GetTraceLog(void)
 
 
 //-----------------------------------------------------------
-class ProfileKeeper : public TriggerObject
-{
+class ProfileKeeper : public TriggerObject {
 public:
-  bool enabled;
-  Processor *cpu;
-  unsigned int last_trace_index;
-  unsigned int instruction_address;
-  unsigned int trace_pc_value;
+  bool enabled = false;
+  Processor *cpu = nullptr;
+  unsigned int last_trace_index = 0;
+  unsigned int instruction_address = 0;
+  unsigned int trace_pc_value = 0;
 
-  ProfileKeeper(void);
-  ~ProfileKeeper(void);
+  ProfileKeeper();
+  ~ProfileKeeper();
 
-  void catchup(void);
-  virtual void callback(void);
-  void enable_profiling(void);
-  void disable_profiling(void);
+  void catchup();
+  virtual void callback() override;
+  void enable_profiling();
+  void disable_profiling();
   void switch_cpus(Processor *new_cpu);
-
 };
 
+
 extern ProfileKeeper profile_keeper;
 
 
@@ -700,10 +712,8 @@ extern ProfileKeeper profile_keeper;
  *
  */
 
-class BoolEventBuffer : public TriggerObject
-{
+class BoolEventBuffer : public TriggerObject {
 public:
-
   guint32  index;               // Index into the buffer
   guint64  *buffer;             // Where the time is stored
   guint32  max_events;          // Size of the event buffer
@@ -711,25 +721,23 @@ public:
   guint64  future_cycle;        // time at which the buffer can store no more data.
   bool     bInitialState;       // State when started.
   bool     bActive;             // True if the buffer is enabled for storing.
-  bool     bFull;               // True if the buffer has been filled.
-
+  bool     bFull = false;       // True if the buffer has been filled.
 
   BoolEventBuffer(bool _initial_state, guint32 _max_events = 4096);
-  ~BoolEventBuffer(void);
+  ~BoolEventBuffer();
   unsigned int get_index(guint64 event_time);
   void activate(bool _initial_state);
-  void deactivate(void);
-  void callback(void);
-  void callback_print(void);
+  void deactivate();
+  void callback();
+  void callback_print();
   inline bool event(bool state);
 
-
-  inline bool isActive(void)
+  inline bool isActive()
   {
     return bActive;
   }
 
-  inline bool isFull(void)
+  inline bool isFull()
   {
     return (index < max_events);
   }
@@ -741,24 +749,26 @@ public:
     buffer a specific event is stored. (e.g. The start bit
     of a usart bit stream.)
    */
-  inline unsigned int get_index(void) {
+  inline unsigned int get_index()
+  {
     return index;
   }
 
-
-  bool get_event(int index) {
-
-    return (index & 1)^bInitialState;
+  bool get_event(int index)
+  {
+    return bool(index & 1) ^ bInitialState;
   }
 
-  bool get_state(guint64 event_time) {
+  bool get_state(guint64 event_time)
+  {
     return get_event(get_index(event_time));
   }
 
-  int get_edges(guint64 start_time, guint64 end_time) {
-    return ( get_index(end_time) - get_index(start_time) );
+  int get_edges(guint64 start_time, guint64 end_time)
+  {
+    return (get_index(end_time) - get_index(start_time));
   }
-
 };
 
+
 #endif
